api.authentication.v1.password package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.password package

## Submodules

## api.authentication.v1.password.password_authenticate module

Autogenerated API

`api.authentication.v1.password.password_authenticate.` `authenticate`(userName: str = None, domain: str = None, password: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session using Password authentication (PUBLIC) Requires password authentication to be enabled on the server, and for the userUse /methods to check which authentication methods are available on the server.

  Return type: | `dict`

## Module contents